@@ -463,12 +463,13 @@ class RedisRoot:
             def django_field_to_redis_field(django_field, redis_root):
 
                 def get_allowed_params(django_field, redis_root):
-                    allowed_params = ['null', 'default', 'choices', 'model']
+                    allowed_params = ['null', 'default', 'choices', 'remote_field']
                     allowed_redis_params = {}
                     for django_field_param_name in django_field.__dict__.keys():
                         if django_field_param_name in allowed_params:
                             value = getattr(django_field, django_field_param_name)
-                            print(django_field, django_field_param_name, value)
+                            if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH]:
+                                value = None
                             if django_field_param_name == 'choices':
                                 real_value = {}
                                 if value is not None:
@@ -477,8 +478,10 @@ class RedisRoot:
                                 else:
                                     real_value = None
                                 value = real_value
-                            elif django_field_param_name == 'model':
-                                value = get_or_create_redis_model_from_django_model(value, redis_root)
+                            elif django_field_param_name == 'remote_field':
+                                if value is not None:
+                                    value = value.model
+                                    value = get_or_create_redis_model_from_django_model(value, redis_root)
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
